# Concepts

## NoTest执行流程图
![](docs/notest_overview.png)

## 用例结构介绍
```yaml
- config:
     testset: ...
     variable_binds: ...
     default_base_url: ...
     generators: ...
- operation:
     ...
- test:
     generator_binds: ...
     group: ...
     name: ...
     url: ...
     method: ...
     headers: ...
     body: ...
     expected_status: ...
     validators: ...
     extract_binds: ...
- test:
     ...
- test:
     ...
```

其中， 

- config部分为testset全局定义区，用来定义全局变量、默认url、数据生成器等全局组件
- test部分为一次测试请求的定义，包括http请求的url、body等字段，以及验证器validator、导出变量extract等操作
- operation部分为工具类操作的定义，包括数据库inset/update等数据准备数据修改等操作

config只有一份，放在最前面，test和operation按需来组织测试场景


